@@ -69,4 +69,21 @@ where
         let response = self.http_client.post(url).json(&request_data).send().await?;
         handle_response::<ResponseDataType, ApiErrorType>(response).await
     }
+    pub async fn put<RequestDataType, ResponseDataType>(&self, request_data: RequestDataType, path: &str) -> CrateResult<ResponseDataType>
+    where
+        RequestDataType: Serialize,
+        ResponseDataType: DeserializeOwned
+    {
+        let url = self.api_base_url.to_string() + path;
+        let response = self.http_client.put(url).json(&request_data).send().await?;
+        handle_response::<ResponseDataType, ApiErrorType>(response).await
+    }
+    pub async fn delete<ResponseDataType>(&self, path: &str) -> CrateResult<ResponseDataType>
+    where
+        ResponseDataType: DeserializeOwned
+    {
+        let url = self.api_base_url.to_string() + path;
+        let response = self.http_client.delete(url).send().await?;
+        handle_response::<ResponseDataType, ApiErrorType>(response).await
+    }
 }
\ No newline at end of file
